@@ -43,6 +43,7 @@ from lino.core.dbutils import resolve_model, resolve_app
 from lino.core import layouts
 #~ from lino.core import changes
 from lino.core import fields
+from lino.core import actions
 
 #~ from lino.core.perms import UserLevels
 #~ from lino.core import perms 
@@ -90,6 +91,17 @@ class EmptyTableRow(VirtualRow):
     
     def filename_root(self):
         return self._table.app_label + '.' + self._table.__name__
+        
+    def __getattr__(self,name):
+        """
+        Since there is only one EmptyTableRow class, we simulate a 
+        getter here by manually creating an InstanceAction.
+        """
+        v = getattr(self._table,name)
+        if isinstance(v,actions.Action):
+            return actions.InstanceAction(v,self._table,self,None)
+        #~ raise Exception("")
+        raise AttributeError("EmptyTableRow on %s has no action '%s'" % (self._table,name))
 
 
 
@@ -278,6 +290,7 @@ class BaseRequest(object):
         else:
             from lino.core.menus import create_item
             mi = create_item(spec)
+            #~ print 20130425, __file__, mi.bound_action
             spec = mi.bound_action.request(**kw)
         spec.setup_from(self)
         #~ ar.user = self.user
