@@ -165,7 +165,17 @@ class ExtRenderer(HtmlRenderer):
                 #return py2js(kw)
             return dict(text=prepare_label(v),menu=dict(items=v.items))
         if isinstance(v,menus.MenuItem):
-            if v.bound_action is not None:
+            if v.instance is not None:
+                h = self.instance_handler(None,v.instance)
+                assert h is not None
+                js = "function() {%s}" % h
+                return self.handler_item(v,js,None)
+                #~ handler = "function(){%s}" % self.instance_handler(v.instance)
+                #~ return dict(text=prepare_label(v),handler=js_code(handler))
+              
+                #~ url = self.get_detail_url(v.instance,an='detail')
+                #~ url = self.get_detail_url(v.instance)
+            elif v.bound_action is not None:
                 if v.params:
                     #~ ar = v.action.actor.request(self.ui,None,v.action,**v.params)
                     ar = v.bound_action.request(**v.params)
@@ -190,16 +200,6 @@ class ExtRenderer(HtmlRenderer):
             #~ elif v.request is not None:
                 #~ raise Exception("20120918 request %r still used?" % v.request)
                 #~ url = self.get_request_url(v.request)
-            elif v.instance is not None:
-                h = self.instance_handler(None,v.instance)
-                assert h is not None
-                js = "function() {%s}" % h
-                return self.handler_item(v,js,None)
-                #~ handler = "function(){%s}" % self.instance_handler(v.instance)
-                #~ return dict(text=prepare_label(v),handler=js_code(handler))
-              
-                #~ url = self.get_detail_url(v.instance,an='detail')
-                #~ url = self.get_detail_url(v.instance)
             else:
                 # a separator
                 #~ return dict(text=v.label)
@@ -840,8 +840,9 @@ tinymce.init({
         Make the dummy messages file.
         But only when generating for root user.
         """
-        if jsgen._for_user_profile == dd.UserProfiles.admin:
-            make_dummy_messages_file(self.linolib_template_name(),messages)
+        if False: # no longer needed because babel extracts them
+            if jsgen._for_user_profile == dd.UserProfiles.admin:
+                make_dummy_messages_file(self.linolib_template_name(),messages)
         
         #~ assert user == jsgen._for_user
         assert profile == jsgen._for_user_profile
@@ -883,7 +884,7 @@ tinymce.init({
                 #~ new_actors_list.append(a)
         #~ actors_list = new_actors_list
         
-        actors_list = [a for a in actors_list if a.get_view_permission(jsgen._for_user_profile)]
+        actors_list = [a for a in actors_list if a.default_action.get_view_permission(jsgen._for_user_profile)]
         
         #~ actors_list = [a for a in actors_list if a.get_view_permission(jsgen._for_user)]
           
