@@ -15,6 +15,8 @@
 This module deserves a better docstring.
 """
 
+from __future__ import unicode_literals
+
 import logging
 logger = logging.getLogger(__name__)
 import os
@@ -30,12 +32,11 @@ from django.conf import settings
 
 class Handle:
   
-    def __init__(self,ui):
-        self.ui = ui
+    def __init__(self):
+        self.ui = settings.SITE.ui
         
     def setup(self,ar):
-        if self.ui is not None:
-            self.ui.setup_handle(self,ar)
+        self.ui.setup_handle(self,ar)
 
 
 ACTION_RESPONSES = frozenset((
@@ -83,6 +84,9 @@ class Callback(object):
         #~ d = Decision(yes,no)
         #~ self.pending_dialogs[d.hash()] = d
         
+    def __repr__(self):
+		return "Callback(%r)" % self.message
+		
     def set_title(self,title):
         self.title = title
         
@@ -105,13 +109,15 @@ class Callback(object):
         
 class UI(object):
     """
+    Base class for UI plugins.
     """
     #~ name = None
     #~ prefix = None
     #~ verbose_name = None
     
-    def __init__(self):
+    def __init__(self,site):
         self.pending_threads = {}
+        self.site = site
             
     #~ def pop_thread(self,id):
         #~ return self.pending_threads.pop(id,None)
@@ -232,6 +238,7 @@ class UI(object):
         #~ return r 
         
     def callback_get(self,request,thread_id,button_id):
+        logger.info("20130409 callback_get")
         thread_id = int(thread_id)
         cb = self.pending_threads.pop(thread_id,None)
         #~ d = self.pop_thread(int(thread_id))
