@@ -973,6 +973,11 @@ class ForeignKeyElement(ComplexRemoteComboFieldElement):
         #~ print 20100903,repr(self.field.rel.to)
         #~ assert issubclass(self.field.rel.to,dd.Model), "%r is not a model" % self.field.rel.to
         #~ pw = getattr(field.rel.to,'_lino_preferred_width',None)
+        if isinstance(field.rel.to,basestring):
+            from lino.core.dbutils import resolve_model
+            field.rel.to = resolve_model(field.rel.to)
+            #~ field.lino_resolve_type()
+            #~ raise Exception("20130507 %s : %s" % (field,field.rel.to))
         pw = field.rel.to.preferred_foreignkey_width
         if pw is not None:
             kw.setdefault('preferred_width',pw)
@@ -1410,7 +1415,16 @@ class SingleRelatedObjectElement(DisplayElement):
         kw.update(
             label=unicode(getattr(relobj.model._meta,'verbose_name',None)) 
                 or relobj.var_name)
-        DisplayElement.__init__(self,lh,relobj.field,**kw)
+        #~ DisplayElement.__init__(self,lh,relobj.field,**kw)
+        
+        #~ kw.setdefault('value','<br/>') # see blog/2012/0527
+        #~ kw.update(always_enabled=True)
+        FieldElement.__init__(self,lh,relobj.field,**kw)
+        #~ self.preferred_height = self.field.preferred_height
+        #~ self.preferred_width = self.field.preferred_width
+        #~ if self.field.max_length:
+            #~ self.preferred_width = self.field.max_length
+        
   
     def add_default_value(self,kw):
         pass
