@@ -47,6 +47,7 @@ from lino.core import actors
 from lino.core import dbtables
 #~ from lino.core import changes
 from lino.core import web
+from lino.core.dbutils import navinfo
 
 
 #~ from lino.ui import requests as ext_requests
@@ -140,10 +141,12 @@ def run_action(ar,elem):
         if elem is None:
             msg = unicode(e)
         else:
+            if isinstance(elem,models.Model):
+                elem = dd.obj2unicode(elem)
             msg = _(
               "Action \"%(action)s\" failed for %(record)s:") % dict(
               action=ar.bound_action.full_name(),
-              record=dd.obj2unicode(elem))
+              record=elem)
             msg += "\n" + unicode(e)
         msg += '.\n' + _(
           "An error report has been sent to the system administrator.")
@@ -238,50 +241,10 @@ def elem2rec_detailed(ar,elem,**rec):
     rec.update(id=elem.pk)
     rec.update(disable_delete=rh.actor.disable_delete(elem,ar))
     if rh.actor.show_detail_navigator:
-        rec.update(navinfo=navinfo(ar,elem))
+        rec.update(navinfo=navinfo(ar.data_iterator,elem))
     return rec
             
-    
 
-def navinfo(ar,elem):
-    first = None
-    prev = None
-    next = None
-    last = None
-    recno = 0
-    message = None
-    LEN = ar.get_total_count()
-    if LEN > 0:
-        # this algorithm is clearly quicker on queries with a few thousand rows
-        id_list = list(ar.data_iterator.values_list('pk',flat=True))
-        """
-        Uncommented the following assert because it failed in certain circumstances 
-        (see `/blog/2011/1220`)
-        """
-        #~ assert len(id_list) == ar.total_count, \
-            #~ "len(id_list) is %d while ar.total_count is %d" % (len(id_list),ar.total_count)
-        #~ print 20111220, id_list
-        try:
-            i = id_list.index(elem.pk)
-        except ValueError:
-            pass
-        else:
-            recno = i + 1
-            first = id_list[0]
-            last = id_list[-1]
-            if i > 0:
-                prev = id_list[i-1]
-            if i < len(id_list) - 1:
-                next = id_list[i+1]
-            message = _("Row %(rowid)d of %(rowcount)d") % dict(rowid=recno,rowcount=LEN)
-    if message is None:
-        message = _("No navigation")
-    return dict(
-        first=first,prev=prev,next=next,last=last,recno=recno,
-        message=message)
-  
-    
-    
 
 
 def delete_element(ar,elem):
@@ -313,17 +276,21 @@ def delete_element(ar,elem):
     
 CATCHED_AJAX_EXCEPTIONS = (Warning,IntegrityError,exceptions.ValidationError)
 
-def ajax_error(e,**kw):
+def ajax_error(e,rh,**kw):
     """
     Utility function that converts a catched exception 
     to a user-friendly error message.
     """
-    logger.info("20130418 ajax_error(%s",e.messages)
     if isinstance(e,exceptions.ValidationError):
+        def fieldlabel(name):
+            de = rh.actor.get_data_elem(name)
+            #~ print 20130423, de
+            return force_unicode(getattr(de,'verbose_name',name))
+        #~ logger.info("20130418 ajax_error(%s",e.messages)
         #~ if isinstance(e.messages,dict):
         md = getattr(e,'message_dict',None)
         if md is not None:
-            e = '<br>'.join(["%s : %s" % kv for kv in md.items()])
+            e = '<br>'.join(["%s : %s" % (fieldlabel(k),v) for k,v in md.items()])
         else:
             e = '<br>'.join(e.messages)
     kw = settings.SITE.ui.error(e,alert=True,**kw)
@@ -340,7 +307,7 @@ def form2obj_and_save(ar,data,elem,is_new,restful,file_upload=False): # **kw2sav
     #~ logger.info('20130321 form2obj_and_save %r', data)
     #~ print 'form2obj_and_save %r' % data
     
-    logger.info('20130418 before calling store.form2obj , elem is %s' % dd.obj2str(elem))
+    #~ logger.info('20130418 before calling store.form2obj , elem is %s' % dd.obj2str(elem))
     # store normal form data (POST or PUT)
     #~ original_state = dict(elem.__dict__)
     if not is_new:
@@ -349,7 +316,7 @@ def form2obj_and_save(ar,data,elem,is_new,restful,file_upload=False): # **kw2sav
         rh.store.form2obj(ar,data,elem,is_new)
         elem.full_clean()
     except CATCHED_AJAX_EXCEPTIONS as e:
-        return ajax_error(e)
+        return ajax_error(e,rh)
         
     kw = dict(success=True)
     
@@ -380,7 +347,7 @@ def form2obj_and_save(ar,data,elem,is_new,restful,file_upload=False): # **kw2sav
         try:
             elem.save(**kw2save)
         except CATCHED_AJAX_EXCEPTIONS,e:
-            return ajax_error(e)
+            return ajax_error(e,rh)
             #~ return views.json_response_kw(success=False,
                   #~ msg=_("There was a problem while saving your data:\n%s") % e)
                   
