@@ -5,22 +5,28 @@ ROOTDIR = Path(__file__).parent.parent
 # load  SETUP_INFO:
 execfile(ROOTDIR.child('lino','setup_info.py'),globals())
 
-from atelier.test import SubProcessTestCase
+from djangosite.utils.pythontest import TestCase
 
 
-class LinoTestCase(SubProcessTestCase):
-    default_environ = dict(DJANGO_SETTINGS_MODULE="lino.projects.std.settings")
+
+class LinoTestCase(TestCase):
+    demo_settings_module = "lino.projects.std.settings"
+    #~ default_environ = dict(DJANGO_SETTINGS_MODULE="lino.projects.std.settings")
     project_root = ROOTDIR
     
+class BlogTest(LinoTestCase):
+    def test_20130316(self): self.run_simple_doctests('docs/blog/2013/0316.rst')
+    def test_20130507(self): self.run_simple_doctests('docs/blog/2013/0507.rst')
+    def test_20130508(self): self.run_simple_doctests('docs/blog/2013/0508.rst')
+    
 class DocsTests(LinoTestCase):
 
     def test_01(self): self.run_docs_django_tests('tutorials.de_BE.settings')
     def test_02(self): self.run_docs_django_tests('tutorials.auto_create.settings')
     def test_03(self): self.run_docs_django_tests('tutorials.human.settings')
-    def test_04(self): self.run_simple_doctests('docs/blog/2013/0316.rst')
     
-    def test_04(self): self.run_django_manage_test('docs/tutorials/polls')
-    def test_04(self): self.run_django_manage_test('docs/tutorials/quickstart')
+    def test_polls(self): self.run_django_manage_test('docs/tutorials/polls')
+    def test_quickstart(self): self.run_django_manage_test('docs/tutorials/quickstart')
 
 
 class UtilsTests(LinoTestCase):
@@ -47,11 +53,14 @@ class PackagesTests(LinoTestCase):
     """
     def test_01(self): self.run_packages_test(SETUP_INFO['packages'])
 
+class CosiTests(LinoTestCase):
+    def test_cosi(self):      self.run_django_admin_test("lino.projects.cosi.settings") # covered by docs/tutorials/quickstart
+    def test_cosi_demo(self): self.run_simple_doctests('docs/tested/test_cosi_demo.rst')
+        
 class ProjectsTests(LinoTestCase):
     
-    def test_cosi(self): self.run_django_admin_test("lino.projects.cosi.settings") # covered by docs/tutorials/quickstart
     def test_events(self): self.run_django_admin_test("lino.projects.events.settings") 
-    def test_presto(self): self.run_django_admin_test("lino.projects.presto.settings") 
+    def test_presto(self): self.run_django_admin_test("lino.projects.presto.test_settings") 
     def test_belref(self): self.run_django_admin_test("lino.projects.belref.settings") 
     def test_babel_tutorial(self): self.run_django_admin_test("lino.projects.babel_tutorial.settings") 
     def test_homeworkschool(self): self.run_django_admin_test("lino.projects.homeworkschool.settings") 
@@ -71,3 +80,9 @@ class TestAppsTests(LinoTestCase):
     def test_quantityfield(self): self.run_django_admin_test("lino.test_apps.quantityfield.settings") 
     
 
+
+#~ class PrestoTest(LinoTestCase):
+    #~ demo_settings_module = "lino.projects.presto.test_settings"
+    
+    #~ def test_presto_demo(self): self.run_docs_django_tests('lino.projects.presto.settings')
+    #~ def test_presto_demo(self): self.run_django_admin_test('lino.projects.presto.settings')
